# Seapopym

[![Poetry](https://img.shields.io/endpoint?url=https://python-poetry.org/badge/v0.json)](https://python-poetry.org/)
[![Documentation Status](https://readthedocs.org/projects/seapopym/badge/?version=latest)](https://seapopym.readthedocs.io/en/latest/?badge=latest)

## Description

Seapodym is a Python package that provides models to simulate the dynamics of low and mid trophic level marine ecosystems. It is designed to be used in the context of the [Spatial Ecosystem And POpulation DYnamics Model (SEAPODYM) project](http://www.seapodym.eu/).

This package was developed by Jules Lehodey as part of his thesis _"Data driven modeling approach of mesozooplankton and micronekton functional groups"_.

## Installation

This package use the [Poetry](https://python-poetry.org/) package manager. To install the package, you can run the following command:

```bash
pip install seapopym
```

PyPi package is available [here](https://pypi.org/project/seapopym/).

Or you can download the source code and run the following command:

```bash
poetry install
```

## Documentation

The documentation is available [here](https://seapopym.readthedocs.io/en/latest/).
